@@ -1,4 +1,5 @@
 import os
+import openpyxl
 from openpyxl import load_workbook
 import pandas as pd
 
@@ -127,4 +128,14 @@ class Excel:
         # try to open an existing workbook
         writer.book = load_workbook(filename)
 
-        return writer.book.sheetnames
\ No newline at end of file
+        return writer.book.sheetnames
+
+    def insert_image(self, filename: str, sheet_name: str) -> None:
+        writer = pd.ExcelWriter(filename, engine='openpyxl', mode='a')
+
+        # try to open an existing workbook
+        writer.book = load_workbook(filename)
+
+        sheet = writer.book.sheetnames[sheet_name]
+        picture = openpyxl.drawing.image.Image(filename)
+        sheet.add_image(picture, 'A1')
\ No newline at end of file
