@@ -2,7 +2,6 @@ from datetime import datetime
 from decimal import Decimal
 import sys
 import re
-from time import strptime
 import unicodedata
 from money import Money
 
@@ -18,7 +17,7 @@ class Types:
 
     @staticmethod
     def to_date(value: str, format: str) -> datetime:
-        return strptime(string=value, format=format)
+        return datetime.strptime(value, format)
 
     @staticmethod
     def to_number(value: any) -> float:
